Grid Signal on the Sphere
=========================

.. autofunction:: e3nn.o3.s2_grid

.. autofunction:: e3nn.o3.spherical_harmonics_s2_grid

.. autofunction:: e3nn.o3.rfft

.. autofunction:: e3nn.o3.irfft

.. autoclass:: e3nn.o3.ToS2Grid
    :members:
    :show-inheritance:

.. autoclass:: e3nn.o3.FromS2Grid
    :members:
    :show-inheritance: